@@ -424,7 +424,7 @@ measure_sheet (GtkWidget      *widget,
     sheet_min = sheet_nat = 0;
   }
 
-  if (self->min_natural_width >= 0)
+  if (orientation == GTK_ORIENTATION_HORIZONTAL && self->min_natural_width >= 0)
     sheet_nat = MAX (sheet_nat, self->min_natural_width);
 
   if (gtk_widget_should_layout (self->drag_handle)) {
@@ -1194,6 +1194,9 @@ get_sheet_width (AdwBottomSheet *self)
 
   width = gtk_widget_get_width (GTK_WIDGET (self));
 
+  if (!self->sheet_bin)
+    return width;
+
   gtk_widget_measure (self->sheet_bin, GTK_ORIENTATION_HORIZONTAL, -1,
                       &sheet_min_width, &sheet_width, NULL, NULL);
 
